==> logtalk-3.81.0_0.any_any.noarch.tbz2: opt/local/share/logtalk-3.81.0-stable/examples/debug_hooks/NOTES.md <==
________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
SPDX-FileCopyrightText: 1998-2023 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________


To load this example and for sample queries, please see the `SCRIPT.txt`
file.

This folder contains a very simple example of using the compiler flag
`hook/1` and the term expansion mechanism to either discard or activate
debugging goals. For debugging goals in clause bodies, one defines clauses
for `goal_expansion/2`. For debugging goals in directives (e.g. in the
`initialization/1` directive), one defines clauses for `term_expansion/2`.

We can use two hook objects, one for developing and debugging code and
one for production code, or a single parametric object. This example
illustrates both approaches although only the first one is used in the
loader auxiliary files and in the sample queries.

==> logtalk-3.86.0_0.any_any.noarch.tbz2: opt/local/share/logtalk-3.86.0-stable/examples/debug_hooks/NOTES.md <==
________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
SPDX-FileCopyrightText: 1998-2023 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________


To load this example and for sample queries, please see the `SCRIPT.txt`
file.

This folder contains a very simple example of using the compiler flag
`hook/1` and the term expansion mechanism to either discard or activate
debugging goals. For debugging goals in clause bodies, one defines clauses
for `goal_expansion/2`. For debugging goals in directives (e.g., in the
`initialization/1` directive), one defines clauses for `term_expansion/2`.

We can use two hook objects, one for developing and debugging code and
one for production code, or a single parametric object. This example
illustrates both approaches although only the first one is used in the
loader auxiliary files and in the sample queries.
